## Hypothesis Update

This is an opportunity to update the state of the current hypothesis based on the results of the tests.

### Updating or Completing the Hypothesis

Based on the results thus far, you need to update the state of the current hypothesis. You can either:
- Mark the current hypothesis as `complete` if the existing test results validate or disprove the hypothesis.
- Mark the current hypothesis as `unverifiable` if the hypothesis cannot be verified due to the current team composition or team member failures.
- Leave the current hypothesis as `unverified` and add new tests to continue our work.
     - If the remaining tests are no longer relevant due to new information, then you will need to include additional tests to the hypothesis - we will action the newest tests first.

### Tips

- We can't interact with the physical world, and you're basically limited to whatever functionality your team members have. Keep this in mind when you are adding new tests.
- Be sure to consider your team member's descriptions. Unless explicitly mentioned, they cannot perform arbitrary tasks and are limited to the functionality provided in their descriptions.
- If any of your new tests required functionality not obviously available to your team members, you should mark the hypothesis as `unverifiable`.
